@@ -18,7 +18,10 @@ from .factory import Record
 
 class Cursor:
 
-    __slots__ = ('_prefetch', '_conn', '_cursor', '_closed', '_put')
+    __slots__ = (
+        '_prefetch', '_conn', '_cursor',
+        '_closed', '_execute'
+    )
 
     def __init__(
             self,
@@ -26,14 +29,16 @@ class Cursor:
             cursor: sqlite3.Cursor,
             prefetch: Optional[int] = None
     ) -> None:
+
         if prefetch is None:
             self._prefetch = conn.prefetch
         else:
             self._prefetch = prefetch
+
         self._conn = conn
         self._cursor = cursor
         self._closed = False
-        self._put = self._conn._put
+        self._execute = conn._execute
 
     async def __aiter__(self) -> AsyncIterator[Record]:
         """Async iterator."""
@@ -54,7 +59,7 @@ class Cursor:
         """Execute the given query."""
         if parameters is None:
             parameters = []
-        await self._put(self._cursor.execute, sql, parameters, timeout=timeout)
+        await self._execute(self._cursor.execute, sql, parameters, timeout=timeout)
         return self
 
     async def executemany(
@@ -65,7 +70,7 @@ class Cursor:
             timeout: Optional[float] = None
     ) -> "Cursor":
         """Execute the given multiquery."""
-        await self._put(self._cursor.executemany, sql, parameters, timeout=timeout)
+        await self._execute(self._cursor.executemany, sql, parameters, timeout=timeout)
         return self
 
     async def executescript(
@@ -75,7 +80,7 @@ class Cursor:
             timeout: Optional[float] = None
     ) -> "Cursor":
         """Execute a user script."""
-        await self._put(self._cursor.executescript, sql_script, timeout=timeout)
+        await self._execute(self._cursor.executescript, sql_script, timeout=timeout)
         return self
 
     async def fetchone(
@@ -84,7 +89,7 @@ class Cursor:
             timeout: Optional[float] = None
     ) -> Optional[Record]:
         """Fetch a single row."""
-        return await self._put(self._cursor.fetchone, timeout=timeout)
+        return await self._execute(self._cursor.fetchone, timeout=timeout)
 
     async def fetchmany(
             self,
@@ -95,7 +100,7 @@ class Cursor:
         """Fetch up to `cursor.arraysize` number of rows."""
         if size is None:
             size = self.arraysize
-        return await self._put(self._cursor.fetchmany, size, timeout=timeout)
+        return await self._execute(self._cursor.fetchmany, size, timeout=timeout)
 
     async def fetchall(
             self,
@@ -103,11 +108,11 @@ class Cursor:
             timeout: Optional[float] = None
     ) -> Iterable[Record]:
         """Fetch all remaining rows."""
-        return await self._put(self._cursor.fetchall, timeout=timeout)
+        return await self._execute(self._cursor.fetchall, timeout=timeout)
 
     async def close(self) -> None:
         """Close the cursor."""
-        await self._put(self._cursor.close)
+        await self._execute(self._cursor.close)
         self._closed = True
 
     @property
